function [x,tri] = gitterL(n)
% Erzeuge Triangulierung eines L-Gebiets.
%
% INPUT: n: Anzahl Intervalle in eine Richtung.
%
    %
    assert(mod(n,2) == 0,'n muss gerade sein.')
    
    % Gitter in eine Richtung.
    xlin = linspace(0,1,n+1);
    
    % Gitter von [0,1]^2.
    [xx,yy] = meshgrid(xlin,xlin);
    x = [xx(:),yy(:)];
    tri = delaunay(x(:,1),x(:,2));
    
    % Berechne Mittelpunkt jedes Elements.
    c = (x(tri(:,1),:) + x(tri(:,2),:) + x(tri(:,3),:))/3;
    
    % Loesche ueberfluessige Elemente.
    tri = tri((c(:,1) <= 0.5) | (c(:,2) >= 0.5),:);
    
    % Einige Punkte werde nicht mehr benoetigt --> Loeschen und Knoten-IDs
    % in 'tri' aktualisieren.
    nodeUsed = false(size(x,1),1);
    nodeUsed(tri(:)) = true;
    map = zeros(size(x,1),1);
    map(nodeUsed) = 1:nnz(nodeUsed);
    tri = map(tri);
    x = x(nodeUsed,:);
end